@@ -1,4 +1,4 @@
-from cachetools import FIFOCache
+from cachetools import Cache, FIFOCache
 from datetime import datetime
 from flask import Flask
 from logging import Logger
@@ -7,7 +7,7 @@ from pypomes_core import (
 )
 from typing import Any, Final
 
-from .common_pomes import _service_token
+from .iam_common import IAM_SERVERS, IamServer, _service_token
 
 KEYCLOAK_CLIENT_ID: Final[str] = env_get_str(key=f"{APP_PREFIX}_KEYCLOAK_CLIENT_ID")
 KEYCLOAK_CLIENT_SECRET: Final[str] = env_get_str(key=f"{APP_PREFIX}_KEYCLOAK_CLIENT_SECRET")
@@ -26,36 +26,6 @@ KEYCLOAK_PUBLIC_KEY_LIFETIME: Final[int] = env_get_int(key=f"{APP_PREFIX}_KEYCLO
                                                        def_value=86400)  # 24 hours
 KEYCLOAK_REALM: Final[str] = env_get_str(key=f"{APP_PREFIX}_KEYCLOAK_REALM")
 KEYCLOAK_URL_AUTH_BASE: Final[str] = env_get_str(key=f"{APP_PREFIX}_KEYCLOAK_URL_AUTH_BASE")
-KEYCLOAK_URL_AUTH_CALLBACK: Final[str] = env_get_str(key=f"{APP_PREFIX}_KEYCLOAK_URL_AUTH_CALLBACK")
-
-# registry structure:
-# {
-#    "client-id": <str>,
-#    "client-secret": <str>,
-#    "client-timeout": <int>,
-#    "public_key": <str>,
-#    "key-lifetime": <int>,
-#    "key-expiration": <int>,
-#    "base-url": <str>,
-#    "callback-url": <str>,
-#    "safe-cache": <FIFOCache>
-# }
-# data in "safe-cache":
-# {
-#    "users": {
-#       "<user-id>": {
-#         "access-token": <str>
-#         "refresh-token": <str>
-#         "access-expiration": <timestamp>,
-#         "login-expiration": <timestamp>,   <-- transient
-#         "login-id": <str>,                 <-- transient
-#       }
-#    }
-# }
-_keycloak_registry: dict[str, Any] = {}
-
-# dafault logger
-_keycloak_logger: Logger | None = None
 
 
 def keycloak_setup(flask_app: Flask,
@@ -69,7 +39,6 @@ def keycloak_setup(flask_app: Flask,
                    login_endpoint: str = KEYCLOAK_ENDPOINT_LOGIN,
                    logout_endpoint: str = KEYCLOAK_ENDPOINT_LOGOUT,
                    base_url: str = KEYCLOAK_URL_AUTH_BASE,
-                   callback_url: str = KEYCLOAK_URL_AUTH_CALLBACK,
                    logger: Logger = None) -> None:
     """
     Configure the Keycloak IAM.
@@ -87,33 +56,26 @@ def keycloak_setup(flask_app: Flask,
     :param login_endpoint: endpoint for redirecting user to JusBR login page
     :param logout_endpoint: endpoint for terminating user access to JusBR
     :param base_url: base URL to request the JusBR services
-    :param callback_url: URL for Keycloak to callback on login
     :param logger: optional logger
     """
     from .iam_pomes import service_login, service_logout, service_callback, service_token
-    global _keycloak_logger, _keycloak_registry
 
-    # establish the logger
-    _keycloak_logger = logger
-
-    # configure the JusBR registry
-    _keycloak_registry = {
+    # configure the Keycloak registry
+    cache: Cache = FIFOCache(maxsize=1048576)
+    cache["users"] = {}
+    IAM_SERVERS[IamServer.IAM_KEYCLOAK] = {
         "client-id": client_id,
         "client-secret": client_secret,
         "client-timeout": client_timeout,
         "base-url": f"{base_url}/realms/{realm}",
-        "callback-url": callback_url,
-        "key-expiration": int(datetime.now(tz=TZ_LOCAL).timestamp()),
-        "key-lifetime": public_key_lifetime,
-        "safe-cache": FIFOCache(maxsize=1048576)
+        "pk-expiration": int(datetime.now(tz=TZ_LOCAL).timestamp()),
+        "pk-lifetime": public_key_lifetime,
+        "cache": cache,
+        "logger": logger,
+        "redirect-uri": None
     }
 
     # establish the endpoints
-    if token_endpoint:
-        flask_app.add_url_rule(rule=token_endpoint,
-                               endpoint="keycloak-token",
-                               view_func=service_token,
-                               methods=["GET"])
     if login_endpoint:
         flask_app.add_url_rule(rule=login_endpoint,
                                endpoint="keycloak-login",
@@ -129,6 +91,11 @@ def keycloak_setup(flask_app: Flask,
                                endpoint="keycloak-callback",
                                view_func=service_callback,
                                methods=["POST"])
+    if token_endpoint:
+        flask_app.add_url_rule(rule=token_endpoint,
+                               endpoint="keycloak-token",
+                               view_func=service_token,
+                               methods=["GET"])
 
 
 def keycloak_get_token(user_id: str,
@@ -142,11 +109,9 @@ def keycloak_get_token(user_id: str,
     :param logger: optional logger
     :return: the uthentication tokem
     """
-    global _keycloak_registry
-
     # retrieve the token
     args: dict[str, Any] = {"user-id": user_id}
-    return _service_token(registry=_keycloak_registry,
+    return _service_token(registry=IAM_SERVERS[IamServer.IAM_KEYCLOAK],
                           args=args,
                           errors=errors,
                           logger=logger)
