@@ -58,8 +58,11 @@ def token_validate(token: str,
     # validate the token
     if not errors:
         token_alg: str = token_header.get("alg")
+        require: list[str] = ["exp", "iat"]
+        if issuer:
+            require.append("iss")
         options: dict[str, Any] = {
-            "require": ["exp", "iat"],
+            "require": require,
             "verify_aud": False,
             "verify_exp": True,
             "verify_iat": True,
